@@ -16,6 +16,8 @@
 
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
+#include <gconf/gconf.h>
+#include <gconf/gconf-client.h>
 
 #include "drivemount.h"
 #include "properties.h"
@@ -36,36 +38,178 @@ typedef struct _ResponseWidgets
 static void handle_response_cb(GtkDialog *dialog, gint response, ResponseWidgets *widgets);
 static void set_widget_sensitivity_false_cb(GtkWidget *widget, GtkWidget *target);
 static void set_widget_sensitivity_true_cb(GtkWidget *widget, GtkWidget *target);
-static void browse_icons_dialog_popup_handler(GnomeIconEntry *entry, GtkWidget *parent_dialog);
-
 static gchar *remove_level_from_path(const gchar *path);
 static void sync_mount_base(DriveData *dd);
 
 void
 properties_load(DriveData *dd)
 {
-	dd->interval = panel_applet_gconf_get_int(PANEL_APPLET(dd->applet), "interval", NULL);
-	dd->device_pixmap = panel_applet_gconf_get_int(PANEL_APPLET(dd->applet), "pixmap", NULL);
-	dd->scale_applet = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "scale", NULL);
-	dd->auto_eject = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "auto-eject", NULL);
-	dd->mount_point = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "mount-point", NULL);
-	dd->autofs_friendly = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "autofs-friendly", NULL);
-	dd->custom_icon_in = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom-icon-mounted", NULL);
-	dd->custom_icon_out = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom-icon-unmounted", NULL);
+	GConfClient *client;
+	gchar *key;
+
+	client = gconf_client_get_default ();
+	key = panel_applet_get_preferences_key (PANEL_APPLET (dd->applet));
+
+	if (gconf_client_dir_exists (client, key, NULL)) {
+		dd->interval = panel_applet_gconf_get_int(PANEL_APPLET(dd->applet), "interval", NULL);
+		dd->device_pixmap = panel_applet_gconf_get_int(PANEL_APPLET(dd->applet), "pixmap", NULL);
+		dd->scale_applet = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "scale", NULL);
+		dd->auto_eject = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "auto-eject", NULL);
+		dd->mount_point = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "mount-point", NULL);
+		dd->autofs_friendly = panel_applet_gconf_get_bool(PANEL_APPLET(dd->applet), "autofs-friendly", NULL);
+		dd->custom_icon_in = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom-icon-mounted", NULL);
+		dd->custom_icon_out = panel_applet_gconf_get_string(PANEL_APPLET(dd->applet), "custom-icon-unmounted", NULL);
+	} else {
+		dd->mount_point = g_strdup("/mnt/floppy");
+		dd->interval = 10;
+	}
+	g_object_unref (G_OBJECT (client));
+	g_free (key);
 	sync_mount_base(dd);
 }
 
-void
-properties_save(DriveData *dd)
+static void
+cb_mount_activate (GtkEntry *entry, gpointer data)
 {
-	panel_applet_gconf_set_int(PANEL_APPLET(dd->applet), "interval", dd->interval, NULL);
-	panel_applet_gconf_set_int(PANEL_APPLET(dd->applet), "pixmap", dd->device_pixmap, NULL);
-	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "scale", dd->scale_applet, NULL);
-	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "auto-eject", dd->auto_eject, NULL);
-	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "mount-point", dd->mount_point, NULL);
-	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "autofs-friendly", dd->autofs_friendly, NULL);
-	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom-icon-mounted", dd->custom_icon_in, NULL);
-	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom-icon-unmounted", dd->custom_icon_out, NULL);
+	DriveData *dd = data;
+	gchar *text;
+	
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	
+	if (!text)
+		return;
+		
+	if (dd->mount_point) {
+		if (!g_strcasecmp (text, dd->mount_point)) {
+			g_free (text);
+			return;
+		}
+		
+		g_free(dd->mount_point);
+		dd->mount_point = g_strdup(text);
+						
+	}
+	else
+		dd->mount_point = g_strdup(text);
+	
+	sync_mount_base (dd);	
+	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "mount-point", 
+				      dd->mount_point, NULL);
+	g_free (text);
+	
+}
+
+static void
+cb_mount_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
+{
+	DriveData *dd = data;
+	
+	cb_mount_activate (GTK_ENTRY (widget), dd);
+	
+}
+
+static void
+spin_changed (GtkSpinButton *button, gpointer data)
+{
+	DriveData *dd = data;
+	
+	dd->interval = gtk_spin_button_get_value_as_int(button);
+	
+	start_callback_update(dd);
+	panel_applet_gconf_set_int(PANEL_APPLET(dd->applet), "interval", 
+				   dd->interval, NULL);
+
+
+}
+
+static void
+scale_toggled (GtkToggleButton *button, gpointer data)
+{
+	DriveData *dd = data;
+	
+	dd->scale_applet = gtk_toggle_button_get_active (button);
+	redraw_pixmap(dd);
+	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "scale", 
+				    dd->scale_applet, NULL);
+	
+}
+
+static void
+eject_toggled (GtkToggleButton *button, gpointer data)
+{
+	DriveData *dd = data;
+	
+	dd->auto_eject = gtk_toggle_button_get_active (button);
+	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "auto-eject", 
+				    dd->auto_eject, NULL);
+	
+}
+
+static void
+automount_toggled (GtkToggleButton *button, gpointer data)
+{
+	DriveData *dd = data;
+	
+	dd->autofs_friendly = gtk_toggle_button_get_active (button);
+	panel_applet_gconf_set_bool(PANEL_APPLET(dd->applet), "autofs-friendly", 
+				    dd->autofs_friendly, NULL);
+	
+}
+
+static void
+omenu_changed (GtkOptionMenu *menu, gpointer data)
+{
+	DriveData *dd = data;
+	gint num;
+	
+	num = gtk_option_menu_get_history (menu);
+	dd->device_pixmap = num < 5 ? num : -1;
+
+	redraw_pixmap(dd);
+	panel_applet_gconf_set_int(PANEL_APPLET(dd->applet), "pixmap", 
+				   dd->device_pixmap, NULL);
+}
+	
+static void
+mount_icon_changed (GnomeIconEntry *entry, gpointer data) 
+{
+	DriveData *dd = data;
+	gchar *temp;
+
+	temp = gnome_icon_entry_get_filename(entry);
+
+	if (!temp)
+		return;
+		
+	if(dd->custom_icon_in) 
+		g_free(dd->custom_icon_in);
+	dd->custom_icon_in = temp;
+	
+	dd->device_pixmap = -1;		
+	redraw_pixmap(dd);
+	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom-icon-mounted",
+				      dd->custom_icon_in, NULL);		
+}
+
+static void
+unmount_icon_changed (GnomeIconEntry *entry, gpointer data) 
+{
+	DriveData *dd = data;
+	gchar *temp;
+	
+	temp = gnome_icon_entry_get_filename(entry);
+	
+	if (!temp)
+		return;
+		
+	if(dd->custom_icon_out) 
+		g_free(dd->custom_icon_out);
+	dd->custom_icon_out = temp;
+	
+	dd->device_pixmap = -1;		
+	redraw_pixmap(dd);
+	panel_applet_gconf_set_string(PANEL_APPLET(dd->applet), "custom-icon-unmounted",
+				      dd->custom_icon_out, NULL);		
 }
 
 void
@@ -85,10 +229,10 @@ properties_show(PanelApplet *applet, gpointer data)
 	gint response;
 
 	widgets = g_new0(ResponseWidgets, 1);
-	dialog = gtk_dialog_new_with_buttons(_("Drive Mount Applet Properties"),
-										 NULL, GTK_DIALOG_MODAL,
-										 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-										 GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+	dialog = gtk_dialog_new_with_buttons(_("Disk Mounter Properties"), NULL, 
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
+					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					     NULL);
 
 	box = GTK_DIALOG(dialog)->vbox;
 	frame = gtk_frame_new("Settings");
@@ -112,12 +256,16 @@ properties_show(PanelApplet *applet, gpointer data)
 	gtk_entry_set_text(GTK_ENTRY(widgets->mount_entry), dd->mount_point);
 	gtk_box_pack_start(GTK_BOX(hbox), widgets->mount_entry , TRUE, TRUE, 0);
 	gtk_widget_show(widgets->mount_entry);
+	g_signal_connect (G_OBJECT (widgets->mount_entry), "activate",
+			  G_CALLBACK (cb_mount_activate), dd);
+	g_signal_connect (G_OBJECT (widgets->mount_entry), "focus_out_event",
+			  G_CALLBACK (cb_mount_focus_out), dd);
 
 	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("Update in seconds:"));
+	label = gtk_label_new(_("Update interval (seconds):"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
@@ -125,8 +273,14 @@ properties_show(PanelApplet *applet, gpointer data)
 	gtk_box_pack_start(GTK_BOX(hbox), widgets->update_spin, FALSE, FALSE, 0);
 	gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON(widgets->update_spin),GTK_UPDATE_ALWAYS);
 	gtk_widget_show(widgets->update_spin);
+	g_signal_connect (G_OBJECT (widgets->update_spin), "value_changed",
+			  G_CALLBACK (spin_changed), dd);
+	
+	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+	gtk_widget_show(hbox);
 
-	label = gtk_label_new(_("Icon:"));
+	label = gtk_label_new(_("Icon :"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
@@ -135,7 +289,9 @@ properties_show(PanelApplet *applet, gpointer data)
 	gtk_widget_show(widgets->omenu);
 	menu = gtk_menu_new();
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(widgets->omenu), menu);
-
+	g_signal_connect (G_OBJECT (widgets->omenu), "changed",
+			  G_CALLBACK (omenu_changed), dd);
+	
 	/* This must be created before the menu items, so we can pass it to a callback */
 	fbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start(GTK_BOX(vbox), fbox, FALSE, FALSE, 0);
@@ -173,6 +329,8 @@ properties_show(PanelApplet *applet, gpointer data)
 	gnome_icon_entry_set_filename(GNOME_ICON_ENTRY(widgets->icon_entry_in), dd->custom_icon_in);
 	gtk_box_pack_end(GTK_BOX(hbox), widgets->icon_entry_in, FALSE, FALSE, 0);
 	gtk_widget_show(widgets->icon_entry_in);
+	g_signal_connect (G_OBJECT (widgets->icon_entry_in), "changed",
+			  G_CALLBACK (mount_icon_changed), dd);
 
 	label = gtk_label_new(_("Custom icon for mounted:"));
 	gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -186,6 +344,8 @@ properties_show(PanelApplet *applet, gpointer data)
 	gnome_icon_entry_set_filename(GNOME_ICON_ENTRY(widgets->icon_entry_out), dd->custom_icon_out);
 	gtk_box_pack_end(GTK_BOX(hbox), widgets->icon_entry_out, FALSE, FALSE, 0);
 	gtk_widget_show(widgets->icon_entry_out);
+	g_signal_connect (G_OBJECT (widgets->icon_entry_out), "changed",
+			  G_CALLBACK (unmount_icon_changed), dd);
 
 	label = gtk_label_new(_("Custom icon for not mounted:"));
 	gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -200,16 +360,22 @@ properties_show(PanelApplet *applet, gpointer data)
 	gtk_box_pack_start(GTK_BOX(vbox), widgets->scale_toggle, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets->scale_toggle), dd->scale_applet);
 	gtk_widget_show(widgets->scale_toggle);
+	g_signal_connect (G_OBJECT (widgets->scale_toggle), "toggled",
+			  G_CALLBACK (scale_toggled), dd);
 
 	widgets->eject_toggle = gtk_check_button_new_with_label (_("Eject on unmount"));
 	gtk_box_pack_start(GTK_BOX(vbox), widgets->eject_toggle, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets->eject_toggle), dd->auto_eject);
 	gtk_widget_show(widgets->eject_toggle);
+	g_signal_connect (G_OBJECT (widgets->eject_toggle), "toggled",
+			  G_CALLBACK (eject_toggled), dd);
 
 	widgets->automount_toggle = gtk_check_button_new_with_label (_("Use automount friendly status test"));
 	gtk_box_pack_start(GTK_BOX(vbox), widgets->automount_toggle, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widgets->automount_toggle), dd->autofs_friendly);
 	gtk_widget_show(widgets->automount_toggle);
+	g_signal_connect (G_OBJECT (widgets->automount_toggle), "toggled",
+			  G_CALLBACK (automount_toggled), dd);
 	gtk_widget_show_all(frame);
 
 	widgets->dd = dd;
@@ -220,38 +386,6 @@ properties_show(PanelApplet *applet, gpointer data)
 static void
 handle_response_cb(GtkDialog *dialog, gint response, ResponseWidgets *widgets)
 {
-	gchar *temp;
-	gint history;
-
-	if(response == GTK_RESPONSE_OK)
-	{
-		temp = (gchar *)gtk_entry_get_text(GTK_ENTRY(widgets->mount_entry));
-		if(widgets->dd->mount_point) g_free(widgets->dd->mount_point);
-		if(temp) widgets->dd->mount_point = g_strdup(temp);
-		else widgets->dd->mount_point = NULL;
-
-		widgets->dd->interval = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(widgets->update_spin));
-
-		history = gtk_option_menu_get_history(GTK_OPTION_MENU(widgets->omenu));
-		widgets->dd->device_pixmap = history < 5 ? history : -1;
-
-		temp = gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(widgets->icon_entry_in));
-		if(widgets->dd->custom_icon_in) g_free(widgets->dd->custom_icon_in);
-		if(temp) widgets->dd->custom_icon_in = temp;
-		else widgets->dd->custom_icon_in = NULL;
-
-		temp = gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(widgets->icon_entry_out));
-		if(widgets->dd->custom_icon_out) g_free(widgets->dd->custom_icon_out);
-		if(temp) widgets->dd->custom_icon_out = temp;
-		else widgets->dd->custom_icon_out = NULL;
-
-		widgets->dd->scale_applet = GTK_TOGGLE_BUTTON(widgets->scale_toggle)->active;
-		widgets->dd->auto_eject = GTK_TOGGLE_BUTTON(widgets->eject_toggle)->active;
-		widgets->dd->autofs_friendly = GTK_TOGGLE_BUTTON(widgets->automount_toggle)->active;
-		redraw_pixmap(widgets->dd);
-		start_callback_update(widgets->dd);
-		properties_save(widgets->dd);
-	}
 	gtk_widget_destroy(GTK_WIDGET(dialog));
 	g_free(widgets);
 }
@@ -268,21 +402,6 @@ set_widget_sensitivity_true_cb(GtkWidget *widget, GtkWidget *target)
 	gtk_widget_set_sensitive(target, TRUE);
 }
 
-static void
-browse_icons_dialog_popup_handler(GnomeIconEntry *entry, GtkWidget *parent_dialog)
-{
-    GtkWidget *dialog;
-
-    g_print("browse called\n");
-
-    dialog = gnome_icon_entry_pick_dialog(entry);
-    if(dialog)
-    {
-        g_print("has dialog\n");
-        gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(parent_dialog));
-    }
-}
-
 static gchar *
 remove_level_from_path(const gchar *path)
 {
