@@ -62,6 +62,13 @@ event_filter (GdkXEvent * gdk_xevent, GdkEvent * event, gpointer data);
 
 static void gkb_destroy (GtkWidget * widget, gpointer data);
 
+void
+set_tooltip (GtkWidget * w, const gchar * tip)
+{
+  GtkTooltips *t = gtk_tooltips_new ();
+  gtk_tooltips_set_tip (t, w, tip, NULL);
+}
+
 void alert(const gchar * str){
  GtkWidget * window;
  window = gnome_message_box_new (str,
@@ -164,9 +171,8 @@ gkb_draw (GKB * gkb)
       gtk_label_set_text (GTK_LABEL (gkb->label2), gkb->keymap->label);
     }
 
- /* TODO: tooltip support
-  applet_widget_set_tooltip (PANEL_APPLET (gkb->applet), gkb->keymap->name);
-  */
+  set_tooltip (gkb->applet, gkb->keymap->name);
+
 }
 
 
