@@ -99,8 +99,6 @@ gkb_prop_map_apply_clicked (GkbMapDialogInfo * mdi)
 
   gkb_prop_list_reload (mdi->pbi);
 
-  gnome_property_box_changed (GNOME_PROPERTY_BOX (mdi->pbi->box));
-
   gtk_widget_set_sensitive (mdi->apply_button, FALSE);
   mdi->changed = FALSE;
 }
@@ -143,10 +141,12 @@ gkb_prop_map_ok_clicked (GkbMapDialogInfo * mdi)
 static void
 gkb_prop_map_help_clicked (GkbMapDialogInfo * mdi)
 {
+/* TODO:
   GnomeHelpMenuEntry help_entry =
     { "gkb_applet", "index.html#GKBAPPLET-PREFS-EDIT" };
 
   gnome_help_display (NULL, &help_entry);
+*/
 }
 
 
@@ -371,10 +371,10 @@ gkb_prop_map_load_stock_button (const gchar * stock_button,
 {
   GtkWidget *button;
 
-  button = gnome_stock_button (stock_button);
+  button = gtk_button_new_from_stock (stock_button);
 
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (gkb_prop_map_button_clicked), mdi);
+  g_signal_connect (button, "clicked",
+		      G_CALLBACK (gkb_prop_map_button_clicked), mdi);
 
   gtk_container_add (GTK_CONTAINER (container), button);
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
@@ -428,8 +428,8 @@ gkb_prop_map_entry_at (GtkWidget * table, gint row, gint col,
 		    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 		    (GtkAttachOptions) (0), 0, 0);
 
-  gtk_signal_connect (GTK_OBJECT (entry), "changed",
-		      GTK_SIGNAL_FUNC (gkb_prop_map_data_changed), mdi);
+  g_signal_connect (entry, "changed",
+		      G_CALLBACK (gkb_prop_map_data_changed), mdi);
 
   return entry;
 }
@@ -468,8 +468,8 @@ gkb_prop_map_combo_at (GtkWidget * table, gint row, gint col,
   if (text)
     gtk_entry_set_text (GTK_ENTRY (entry), text);
 
-  gtk_signal_connect (GTK_OBJECT (entry), "changed",
-		      GTK_SIGNAL_FUNC (gkb_prop_map_data_changed), mdi);
+  g_signal_connect (entry, "changed",
+		      G_CALLBACK (gkb_prop_map_data_changed), mdi);
 
   return entry;
 }
@@ -498,10 +498,10 @@ gkb_prop_map_pixmap_at (GtkWidget * table, gint row, gint col,
 		    (GtkAttachOptions) (GTK_FILL),
 		    (GtkAttachOptions) (GTK_FILL), 0, 0);
 
-  gnome_icon_entry_set_icon (GNOME_ICON_ENTRY (icon_entry), flag);
+  gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (icon_entry), flag);
 
-  gtk_signal_connect (GTK_OBJECT (GNOME_ICON_ENTRY (icon_entry)->pickbutton),
-		      "clicked", GTK_SIGNAL_FUNC (gkb_prop_map_data_changed),
+  g_signal_connect (icon_entry,
+		      "changed", G_CALLBACK (gkb_prop_map_data_changed),
 		      mdi);
 
   return icon_entry;
@@ -644,16 +644,17 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
   button_box = GTK_CONTAINER (gtk_hbutton_box_new ());
   gtk_box_pack_start (GTK_BOX (vbox2), GTK_WIDGET (button_box), TRUE, TRUE,
 		      0);
-  mdi->ok_button =
-    gkb_prop_map_load_stock_button (GNOME_STOCK_BUTTON_OK, button_box, mdi);
+  mdi->help_button =
+    gkb_prop_map_load_stock_button (GNOME_STOCK_BUTTON_HELP, button_box, mdi);
   mdi->apply_button =
     gkb_prop_map_load_stock_button (GNOME_STOCK_BUTTON_APPLY, button_box,
 				    mdi);
   mdi->close_button =
     gkb_prop_map_load_stock_button (GNOME_STOCK_BUTTON_CLOSE, button_box,
 				    mdi);
-  mdi->help_button =
-    gkb_prop_map_load_stock_button (GNOME_STOCK_BUTTON_HELP, button_box, mdi);
+  mdi->ok_button =
+    gkb_prop_map_load_stock_button (GNOME_STOCK_BUTTON_OK, button_box, mdi);
+
   gtk_widget_set_sensitive (mdi->apply_button, FALSE);
 
   /* Go, go go !! */
